@@ -273,7 +273,7 @@ class DrawArea:
 
 		logging.debug('<<')
 
-	def drawPlot(self,xvalues,yvalues,xlabel,ylabel,title,color,zones=None,xzones=None):
+	def drawPlot(self,xvalues,yvalues,xlabel,ylabel,title,color,zones=None,xzones=None, ylimits=None):
 		logging.debug('>>')  
 		logging.debug("Type: plot | title: "+str(title)+" | col: "+str(color)+" | xlabel: "+str(xlabel)+" | ylabel: "+str(ylabel))
 		logging.debug('xlabel: '+str(xlabel)+' | ylabel: '+str(ylabel)+' | title: '+str(title))
@@ -315,6 +315,15 @@ class DrawArea:
 		else:
 			axis.set_title("%s" %(ylabel[0]))
 
+		ylim_min, ylim_max = axis.get_ylim()
+		if ylimits is not None:
+			logging.debug("Using ylimits: %s" % str(ylimits))
+			if ylimits[0] is not None:
+				ylim_min = ylimits[0]
+			if ylimits[1] is not None:
+				ylim_max = ylimits[1]
+			axis.set_ylim(ylim_min, ylim_max)
+
 		canvas = FigureCanvasGTK(figure) # a gtk.DrawingArea
 		canvas.show()
 		self.vbox.pack_start(canvas, True, True)
@@ -323,8 +332,9 @@ class DrawArea:
 		
 		for child in self.vbox.get_children():
 			logging.debug('Child available: '+str(child))
-
+		
 		logging.debug('<<')
+		return (ylim_min, ylim_max)
 	
 	def drawPie(self,xvalues,yvalues,xlabel,ylabel,title,color,zones=None):
 		logging.debug('>>')
