@@ -52,6 +52,8 @@ class Main(SimpleGladeApp):
 		self.block = False
 		self.activeSport = None
 		self.gpxDir = gpxDir
+		self.record_list = None
+		self.laps = None
 
 	def new(self):
 		self.testimport = self.parent.testimport
@@ -78,9 +80,12 @@ class Main(SimpleGladeApp):
 		self.notebook.set_current_page(1)
 
 		#Disable import menu item unless specified on startup
-		if not self.testimport:
-			self.menu_importdata.set_sensitive(0)
-	
+		self.set_unified_import(self.testimport)
+			
+	def set_unified_import(self, status=False):
+		self.menu_importdata.set_sensitive(status)
+		self.parent.testimport = status
+			
 	def _createXmlListView(self,file):
 		menufile = XMLParser(file)
 		savedOptions = []
@@ -99,6 +104,12 @@ class Main(SimpleGladeApp):
 		for widget in self.menuitem1_menu:
 			if widget.get_name() == plugin[1]:
 				self.menuitem1_menu.remove(widget)
+				
+	def removeExtension(self, extension):
+		for widget in self.recordbuttons_hbox:
+			if widget.get_name() == extension[1]:
+				logging.debug("Removing extension: %s " % extension[0])
+				self.recordbuttons_hbox.remove(widget)
 
 	def addImportPlugin(self,plugin):
 		button = gtk.MenuItem(plugin[0])
@@ -108,21 +119,24 @@ class Main(SimpleGladeApp):
 		self.menuitem1_menu.show_all()
 
 	def addExtension(self,extension):
-		txtbutton,extensioncode,extensiontype = extension
-		button = gtk.Button(txtbutton)
+		#txtbutton,extensioncode,extensiontype = extension
+		button = gtk.Button(extension[0])
+		button.set_name(extension[1])
 		button.connect("button_press_event", self.runExtension, extension)
 		self.recordbuttons_hbox.pack_start(button,False,False,0)
 		self.recordbuttons_hbox.show_all()
 
 	def runExtension(self,widget,widget2,extension):
+		#print extension
 		txtbutton,extensioncode,extensiontype = extension
+		id = None
 		if extensiontype=="record":
-    			selected,iter = self.recordTreeView.get_selection().get_selected()
+			selected,iter = self.recordTreeView.get_selection().get_selected()
 			id = selected.get_value(iter,0)
 		self.parent.runExtension(extension,id)
 
 	def createGraphs(self,RecordGraph,DayGraph,WeekGraph, MonthGraph,YearGraph,HeartRateGraph):
-		self.drawarearecord = RecordGraph(self.record_vbox, self.window1, self.record_combovalue, self.record_combovalue2, self.btnShowLaps)
+		self.drawarearecord = RecordGraph(self.record_graph_vbox, self.window1, self.record_combovalue, self.record_combovalue2, self.btnShowLaps, self.tableConfig)
 		self.drawareaheartrate = HeartRateGraph(self.heartrate_vbox, self.window1, self.heartrate_vbox2)
 		#self.drawareaday = DayGraph(self.day_vbox, self.day_combovalue)
 		self.day_vbox.hide()
@@ -130,8 +144,9 @@ class Main(SimpleGladeApp):
 		self.drawareamonth = MonthGraph(self.month_vbox, self.window1, self.month_combovalue,self.month_combovalue2)
 		self.drawareayear = YearGraph(self.year_vbox, self.window1, self.year_combovalue,self.year_combovalue2)
 	
-	def createMap(self,Googlemaps,waypoint, useGM3):
-		self.googlemaps = Googlemaps(self.data_path, self.map_vbox,waypoint, useGM3)
+	def createMap(self,Googlemaps,waypoint):
+		self.googlemaps = Googlemaps(self.data_path, self.map_vbox,waypoint, pytrainer_main=self.parent)
+		self.googlemaps_old = Googlemaps(self.data_path, self.map_vbox_old,waypoint, pytrainer_main=self.parent)
 
 	def updateSportList(self,listSport): 
 		logging.debug(">>")
@@ -247,13 +262,17 @@ class Main(SimpleGladeApp):
 			buffer.set_text(comments)
 
 		else:
+			self.recordview.set_current_page(0)
 			self.recordview.set_sensitive(0)
 		logging.debug(">>")
 
 	def actualize_recordgraph(self,record_list,laps=None):
 		logging.debug(">>")
+		self.record_list = record_list
+		self.laps = laps
 		if len(record_list)>0:
 			self.record_vbox.set_sensitive(1)
+			self.drawarearecord.drawgraph(record_list,laps)
 		else:
 			#Remove graph
 			vboxChildren = self.record_vbox.get_children()
@@ -265,8 +284,6 @@ class Main(SimpleGladeApp):
 					logging.debug('Removing child: '+str(child))
 					self.record_vbox.remove(child)
 			self.record_vbox.set_sensitive(0)
-		#logging.debug("Going to draw "+str(record_list))
-		self.drawarearecord.drawgraph(record_list,laps)
 		logging.debug("<<")
 	
 	def actualize_heartrategraph(self,record_list):
@@ -377,9 +394,12 @@ class Main(SimpleGladeApp):
 		self.drawareaday.drawgraph(record_list)
 		logging.debug("<<")
 	
-	def actualize_map(self,id_record):
+	def actualize_map(self,id_record, full_screen=False):
 		logging.debug(">>")
-		self.googlemaps.drawMap(id_record)
+		if full_screen:
+			self.googlemaps_old.drawMap(id_record)
+		else:
+			self.googlemaps.drawMap(id_record)
 		logging.debug("<<")
 	
 	def actualize_weekview(self, record_list, date_ini, date_end):
@@ -686,13 +706,28 @@ class Main(SimpleGladeApp):
 			self.waypoint_longitude.set_text(str(record_list[default_id][2]))
 			self.waypoint_name.set_text(str(record_list[default_id][6]))
 			self.waypoint_description.set_text(str(record_list[default_id][4]))
-			self.waypoint_type.insert_text(0,str(record_list[default_id][7]))
-			self.waypoint_type.set_active(0)
+			self.set_waypoint_type(str(record_list[default_id][7]))
 		if redrawmap == 1:
 			self.waypointeditor.createHtml(default_waypoint)
 			self.waypointeditor.drawMap()
 		logging.debug("<<")
 	
+	def set_waypoint_type(self, type):
+		x = 0
+		tree_model = self.waypoint_type.get_model()
+		if tree_model is not None:
+			#iter = tree_model.get_iter_root()
+			for item in tree_model:
+				#if isinstance(item, gtk.TreeModelRow):
+				if item[0] == type:
+					self.waypoint_type.set_active(x)
+					return
+				x += 1
+		self.waypoint_type.insert_text(0, type)
+		self.waypoint_type.set_active(0)
+		return
+			
+	
 	def on_waypointTreeView_button_press(self, treeview, event):
 		x = int(event.x)
 		y = int(event.y)
@@ -782,12 +817,32 @@ class Main(SimpleGladeApp):
 				menuItems[numcolumn-1].set_active(visible)
 		self.menublocking = 1
 	
-	def createWaypointEditor(self,WaypointEditor,waypoint):
-		self.waypointeditor = WaypointEditor(self.data_path, self.waypointvbox,waypoint)
+	def createWaypointEditor(self,WaypointEditor,waypoint, parent=None):
+		self.waypointeditor = WaypointEditor(self.data_path, self.waypointvbox,waypoint,parent)
+		
+	def zoom_graph(self, ylimits=None):
+		logging.debug(">>")
+		logging.debug("Reseting graph Y axis with ylimits: %s" % str(ylimits) )
+		self.drawarearecord.drawgraph(self.record_list,self.laps, ylimits=ylimits)
+		logging.debug("<<")
 
 	######################
 	## Lista de eventos ##
 	######################
+	
+	def on_spinbuttonY1_value_changed(self, widget):
+		ymin = self.spinbuttonY1Min.get_value()
+		ymax = self.spinbuttonY1Max.get_value()
+		#Check to see if the min and max have the same...
+		if ymin == ymax: 
+			if widget.get_name() == "spinbuttonY1Min": #User was changing the min spinbutton, so move max up
+				ymax += 1
+			else:	#Move min down
+				ymin -= 1
+		self.zoom_graph(ylimits=(ymin, ymax))
+	
+	def on_buttonResetGraph_clicked(self, widget):
+		self.zoom_graph()
 
 	def on_edit_clicked(self,widget):
 		selected,iter = self.recordTreeView.get_selection().get_selected()
@@ -847,7 +902,7 @@ class Main(SimpleGladeApp):
 	def on_showmap_clicked(self,widget):
 		self.infoarea.hide()
 		self.maparea.show()
-		self.parent.refreshMapView()
+		self.parent.refreshMapView(full_screen=True)
 	
 	def on_hidemap_clicked(self,widget):
 		self.maparea.hide()
@@ -878,11 +933,11 @@ class Main(SimpleGladeApp):
 		if self.block:
 			self.block = False
 		else:
-			self.parent.refreshListRecords()
-			self.parent.refreshGraphView(self.selected_view)
 			if self.selected_view == "record":
 				self.recordview.set_current_page(0)
 				self.parent.refreshRecordGraphView("info")
+			self.parent.refreshListRecords()
+			self.parent.refreshGraphView(self.selected_view)
 
 	def on_calendar_changemonth(self,widget):
 		logging.debug("--")
@@ -926,6 +981,7 @@ class Main(SimpleGladeApp):
 	def on_gpsplugins_activate(self,widget):
 		self.parent.editGpsPlugins()
 	#hasta aqui revisado
+	
 	def on_allRecordTreeView_button_press(self, treeview, event):
 		logging.debug(">>")
 		#print "on_allRecordTreeView_"
@@ -951,37 +1007,6 @@ class Main(SimpleGladeApp):
 		logging.debug("<<")
 		return False
 	
-	'''def actualize_recordTreeView(self, record_list):
-		logging.debug(">>")
-		iterOne = False
-		store = gtk.ListStore(
-			gobject.TYPE_INT,
-			gobject.TYPE_STRING,
-			gobject.TYPE_STRING,
-			gobject.TYPE_STRING,
-			object)
-		for i in record_list:
-			iter = store.append()
-			if not iterOne:
-				iterOne = iter
-			dateTime = i[12]
-			if dateTime is not None:
-				localTime = dateutil.parser.parse(dateTime).strftime("%H:%M")
-			else:
-				localTime = ""
-			store.set (
-				iter,
-				0, int(i[8]),
-				1, str(localTime),
-				2, str(i[0]),
-				3, str(i[2])
-				)
-		self.recordTreeView.set_model(store)
-		if iterOne:
-			self.recordTreeView.get_selection().select_iter(iterOne)
-		logging.debug("<<")
-		#if len(record_list)>0:'''
-
 	def actualize_recordTreeView(self, record_list):
 		logging.debug(">>")
 		iterOne = False
@@ -992,13 +1017,9 @@ class Main(SimpleGladeApp):
 			gobject.TYPE_STRING,		#Distance
 			object)
 		for i in record_list:
-			#Get lap info #TODO refactor to use a database table
-			gpxfile =  "%s/%s.gpx" %(self.gpxDir, i[8])
-			laps = None
-			if os.path.isfile(gpxfile):
-				gpx = Gpx(self.data_path,gpxfile)
-				laps = gpx.getLaps() #(elapsedTime, lat, lon, calories, distance)
-			#print gpxfile, laps
+			#Get lap info 
+			id_record = i[8]
+			laps = self.parent.record.getLaps(id_record)
 			iter = store.append(None)
 			if not iterOne:
 				iterOne = iter
@@ -1016,11 +1037,12 @@ class Main(SimpleGladeApp):
 				)
 			if laps is not None:
 				for lap in laps:
-					lapNumber = "%s%d" % ( _("lap"), (laps.index(lap)+1) )
-					distance = "%0.2f" % (float(lap[4]) / 1000.0)
-					timeHours = int(float(lap[0]) / 3600)
-					timeMin = int((float(lap[0]) / 3600.0 - timeHours) * 60)
-					timeSec = float(lap[0]) - (timeHours * 3600) - (timeMin * 60) 
+					#"id_lap, record, elapsed_time, distance, start_lat, start_lon, end_lat, end_lon, calories, lap_number",  
+					lapNumber = "%s%d" % ( _("lap"), int(lap[9])+1 ) 
+					distance = "%0.2f" % (float(lap[3]) / 1000.0)
+					timeHours = int(float(lap[2]) / 3600)
+					timeMin = int((float(lap[2]) / 3600.0 - timeHours) * 60)
+					timeSec = float(lap[2]) - (timeHours * 3600) - (timeMin * 60) 
 					if timeHours > 0:
 						duration = "%d%s%02d%s%02d%s" % (timeHours, _("h"), timeMin, _("m"), timeSec, _("s"))
 					else:
@@ -1076,12 +1098,12 @@ class Main(SimpleGladeApp):
 		self.actualize_yearview()
 	
 	def on_recordTree_clicked(self,widget,num,num2):
-    		selected,iter = self.recordTreeView.get_selection().get_selected()
+		selected,iter = self.recordTreeView.get_selection().get_selected()
 		self.parent.editRecord(selected.get_value(iter,0))
 
 	######## waypoints events ##########
 	def on_savewaypoint_clicked(self,widget):
-    		selected,iter = self.waypointTreeView.get_selection().get_selected()
+		selected,iter = self.waypointTreeView.get_selection().get_selected()
 		id_waypoint = selected.get_value(iter,0)
 		lat = self.waypoint_latitude.get_text()
 		lon = self.waypoint_longitude.get_text()
@@ -1091,7 +1113,7 @@ class Main(SimpleGladeApp):
 		self.parent.updateWaypoint(id_waypoint,lat,lon,name,desc,sym)
 	
 	def on_removewaypoint_clicked(self,widget):
-    		selected,iter = self.waypointTreeView.get_selection().get_selected()
+		selected,iter = self.waypointTreeView.get_selection().get_selected()
 		id_waypoint = selected.get_value(iter,0)
 		self.parent.removeWaypoint(id_waypoint)
 
