@@ -46,12 +46,14 @@ hrTag = gpxdataNS.substitute(tag="hr")
 cadTag = gpxdataNS.substitute(tag="cadence")
 lapTag = gpxdataNS.substitute(tag="lap")
 endPointTag = gpxdataNS.substitute(tag="endPoint")
+startPointTag = gpxdataNS.substitute(tag="startPoint")
 elapsedTimeTag = gpxdataNS.substitute(tag="elapsedTime")
 distanceTag = gpxdataNS.substitute(tag="distance")
 
 class Gpx:
 	def __init__(self, data_path = None, filename = None, trkname = None):
 		logging.debug(">>")
+		global mainNS, timeTag, trackTag, trackPointTag, trackPointTagLast,	trackSegTag, elevationTag, nameTag
 		self.data_path = data_path
 		self.filename = filename
 		self.trkname = trkname
@@ -63,14 +65,38 @@ class Gpx:
 		self.unegative = 0
 		self.maxvel = 0
 		self.maxhr = 0
+		self.hr_average = 0
 		self.date = ""
 		#self.Date = Date()
 		self.calories= 0
+		self.tree = None
 		if filename != None:
 			if not os.path.isfile(self.filename):
 				return None
 			logging.debug("parsing content from "+self.filename)
 			self.tree = etree.ElementTree(file=filename).getroot()
+			if self.tree.get("version") == "1.0":
+				#Got an old GPX file
+				logging.debug("Old gpx version")
+				mainNS = string.Template(".//{http://www.topografix.com/GPX/1/0}$tag")
+				timeTag = mainNS.substitute(tag="time")
+				trackTag = mainNS.substitute(tag="trk")
+				trackPointTag = mainNS.substitute(tag="trkpt")
+				trackPointTagLast = mainNS.substitute(tag="trkpt[last()]")
+				trackSegTag = mainNS.substitute(tag="trkseg")
+				elevationTag = mainNS.substitute(tag="ele")
+				nameTag = mainNS.substitute(tag="name")
+			else:
+				logging.debug("Importing version %s gpx file" % self.tree.get("version"))
+				mainNS = string.Template(".//{http://www.topografix.com/GPX/1/1}$tag")
+				timeTag = mainNS.substitute(tag="time")
+				trackTag = mainNS.substitute(tag="trk")
+				trackPointTag = mainNS.substitute(tag="trkpt")
+				trackPointTagLast = mainNS.substitute(tag="trkpt[last()]")
+				trackSegTag = mainNS.substitute(tag="trkseg")
+				elevationTag = mainNS.substitute(tag="ele")
+				nameTag = mainNS.substitute(tag="name")
+				
 			logging.debug("getting values...")
 			self.Values = self._getValues()
 		logging.debug("<<")
@@ -120,6 +146,8 @@ class Gpx:
 	def getLaps(self):
 		logging.debug(">>")
 		lapInfo = []
+		if self.tree is None:
+			return lapInfo
 		tree  = self.tree
 		#date = tree.findtext(timeTag)
 		#startTime = self.getDateTime(date)
@@ -128,6 +156,12 @@ class Gpx:
 			endPoint = lap.find(endPointTag)
 			lat = endPoint.get("lat")
 			lon = endPoint.get("lon")
+			startPoint = lap.find(startPointTag)
+			if startPoint is not None:
+				stLat = startPoint.get("lat")
+				stLon = startPoint.get("lon")
+			else:
+				stLat, stLon = "",""
 			elapsedTime = lap.findtext(elapsedTimeTag)
 			if elapsedTime.count(":") == 2: # got a 0:41:42.14 type elasped time
 				hours, mins, secs = elapsedTime.split(":")
@@ -136,7 +170,7 @@ class Gpx:
 			calories = lap.findtext(calorieTag)
 			distance = lap.findtext(distanceTag)
 			logging.debug("Found time: %s, lat: %s lon: %s cal: %s dist: %s " % (elapsedTime, lat, lon, calories, distance))
-			lapInfo.append((elapsedTime, lat, lon, calories, distance))
+			lapInfo.append((elapsedTime, lat, lon, calories, distance, stLat, stLon))
 		return lapInfo
 	
 	def _getValues(self): 
@@ -147,35 +181,43 @@ class Gpx:
 		tree  = self.tree
 		# Calories data comes within laps. Maybe more than one, adding them together - dgranda 20100114
 		laps = tree.findall(lapTag)
-		for lap in laps:
-			lapCalories = lap.findtext(calorieTag)
-			logging.debug("Lap calories: "+str(lapCalories))
-			self.calories += int(lapCalories)
-		logging.debug("Calories: "+str(self.calories))
+		if laps is not None and laps != "":
+			for lap in laps:
+				lapCalories = lap.findtext(calorieTag)
+				logging.debug("Lap calories: "+str(lapCalories))
+				self.calories += int(lapCalories)
+			logging.debug("Calories: "+str(self.calories))
+		else:
+			laps = []
 
 		retorno = []
 		his_vel = []
-		last_lat = "False"
-		last_lon = "False"
-		last_time = "False"
+		last_lat = None
+		last_lon = None
+		last_time = None
 		total_dist = 0
+		dist_elapsed = 0 # distance since the last time found
 		total_hr = 0
 		tmp_alt = 0
 		len_validhrpoints = 0
-
 		trkpoints = tree.findall(trackPointTag)
-		if not len(trkpoints):
+		if trkpoints is None or len(trkpoints) == 0:
+			logging.debug( "No trkpoints found in file")
 			return retorno
+		logging.debug("%d trkpoints in file" % len(trkpoints))
 		
 		date_ = tree.find(timeTag).text
 		#mk_time = self.getDateTime(date_)[0] #UTC Date
 		mk_time = self.getDateTime(date_)[1] #Local Date
 		self.date = mk_time.strftime("%Y-%m-%d")
+		waiting_points = []
+
 
 		for trkpoint in trkpoints:
 			lat = trkpoint.get("lat")
 			lon = trkpoint.get("lon")
 			if lat is None or lat == "" or lon is None or lon == "":
+				logging.debug("lat or lon is blank")
 				continue
 			#get the heart rate value from the gpx extended format file
 			hrResult = trkpoint.find(hrTag)
@@ -197,7 +239,7 @@ class Gpx:
 				mk_time = self.getDateTime(date_)[0]
 				time_ = time.mktime(mk_time.timetuple()) #Convert date to seconds
 			else:
-				time_ = 1
+				time_ = None
 			#get the elevation
 			eleResult = trkpoint.find(elevationTag)
 			if eleResult is not None:
@@ -219,46 +261,84 @@ class Gpx:
 				#Convert lat and lon from degrees to radians
 				tmp_lat = float(lat)*0.01745329252  #0.01745329252 = number of radians in a degree
 				tmp_lon = float(lon)*0.01745329252  #57.29577951 = 1/0.01745329252 or degrees per radian
-				tmp_time = int(time_)
+				#tmp_time = int(time_)
 		
 				#Para las vueltas diferentes a la primera / For the returns different from first	
-				if last_lat != "False":
-					time_ = tmp_time - last_time
-					if time_>0:
-						#Caqlculate diference betwen last and new point
-						#tempnum=(math.sin(last_lat)*math.sin(tmp_lat))+(math.cos(last_lat)*math.cos(tmp_lat)*math.cos(tmp_lon-last_lon))
-						#try:
-						#Pasamos la distancia de radianes a metros..  creo / We convert the distance from radians to meters
-						#David no me mates que esto lo escribi hace anhos / Do not kill me this was written ages ago
-						#http://faculty.washington.edu/blewis/ocn499/EXER04.htm equation for the distance between 2 points on a spherical earth
-						try:
-							#dist=math.acos(tempnum)*111.302*57.29577951
-							dist=math.acos((math.sin(last_lat)*math.sin(tmp_lat))+(math.cos(last_lat)*math.cos(tmp_lat)*math.cos(tmp_lon-last_lon)))*111.302*57.29577951
-						except:
-							dist=0
-						total_dist += dist
-						total_hr += hr
-						if hr>self.maxhr:
-							self.maxhr = hr
-						#dividimos kilometros por hora (no por segundo) / Calculate kilometers per hour (not including seconds)
-						tmp_vel = dist/((time_)/3600.0)
-						vel,his_vel = self._calculate_velocity(tmp_vel,his_vel, 3)
-						#si la velocidad es menor de 90 lo damos por bueno / if speed is greater than 90 or time greater than 100 we exclude the result
-						if vel<90 and time_ <100:
-							if vel>self.maxvel:
-								self.maxvel=vel
-							self.total_time += time_
-							retorno.append((total_dist,tmp_alt, self.total_time,vel,lat,lon,hr,cadence))
-							rel_alt = tmp_alt - last_alt #Could allow for some 'jitter' in height here
-							if rel_alt > 0:
-								self.upositive += rel_alt
-							elif rel_alt < 0:
-								self.unegative -= rel_alt
+				if last_lat is not None:
+					#time_ = tmp_time - last_time
+					#if time_>0:
+					#Caqlculate diference betwen last and new point
+					#tempnum=(math.sin(last_lat)*math.sin(tmp_lat))+(math.cos(last_lat)*math.cos(tmp_lat)*math.cos(tmp_lon-last_lon))
+					#try:
+					#Pasamos la distancia de radianes a metros..  creo / We convert the distance from radians to meters
+					#David no me mates que esto lo escribi hace anhos / Do not kill me this was written ages ago
+					#http://faculty.washington.edu/blewis/ocn499/EXER04.htm equation for the distance between 2 points on a spherical earth
+					try:
+						#dist=math.acos(tempnum)*111.302*57.29577951
+						dist=math.acos((math.sin(last_lat)*math.sin(tmp_lat))+(math.cos(last_lat)*math.cos(tmp_lat)*math.cos(tmp_lon-last_lon)))*111.302*57.29577951
+					except:
+						dist=0
+					dist_elapsed += dist
+					total_dist += dist
+					total_hr += hr
+					if hr>self.maxhr:
+						self.maxhr = hr
+					#if time_>0:
+					#	#dividimos kilometros por hora (no por segundo) / Calculate kilometers per hour (not including seconds)
+					#	tmp_vel = dist/((time_)/3600.0)
+					#	vel,his_vel = self._calculate_velocity(tmp_vel,his_vel, 3)
+					#	#si la velocidad es menor de 90 lo damos por bueno / if speed is greater than 90 or time greater than 100 we exclude the result
+					#	if vel<90 and time_ <100:
+					#		if vel>self.maxvel:
+					#			self.maxvel=vel
+					#		self.total_time += time_
+					if time_ is not None:
+						tmp_time = int(time_)
+						time_elapsed = tmp_time - last_time if last_time is not None else 0
+						if time_elapsed>0:
+							#Caqlculate diference betwen last and new point
+							#tempnum=(math.sin(last_lat)*math.sin(tmp_lat))+(math.cos(last_lat)*math.cos(tmp_lat)*math.cos(tmp_lon-last_lon))
+							#try:
+							#Pasamos la distancia de radianes a metros..  creo / We convert the distance from radians to meters
+							#David no me mates que esto lo escribi hace anhos / Do not kill me this was written ages ago
+							#http://faculty.washington.edu/blewis/ocn499/EXER04.htm equation for the distance between 2 points on a spherical earth
+							#dividimos kilometros por hora (no por segundo) / Calculate kilometers per hour (not including seconds)
+							tmp_vel = dist_elapsed/((time_elapsed)/3600.0)
+							vel,his_vel = self._calculate_velocity(tmp_vel,his_vel, 3)
+							#si la velocidad es menor de 90 lo damos por bueno / if speed is greater than 90 we exclude the result
+							self.total_time += time_elapsed
+							if vel<90:
+								if vel>self.maxvel:
+									self.maxvel=vel
+								for ((w_total_dist, w_dist, w_alt, w_total_time, w_lat, w_lon, w_hr, w_cadence)) in waiting_points:
+									w_time = (w_dist/dist_elapsed) * time_elapsed
+									w_vel = w_dist/((w_time)/3600.0)
+									w_total_time += w_time
+									retorno.append((w_total_dist, w_alt, w_total_time, w_vel, w_lat, w_lon, w_hr, w_cadence))
+								waiting_points = []
+								retorno.append((total_dist,tmp_alt, self.total_time,vel,lat,lon,hr,cadence))
+								rel_alt = tmp_alt - last_alt #Could allow for some 'jitter' in height here
+								if rel_alt > 0:
+									self.upositive += rel_alt
+								elif rel_alt < 0:
+									self.unegative -= rel_alt
+							dist_elapsed = 0
+					else:
+						waiting_points.append((total_dist, dist_elapsed, tmp_alt, self.total_time, lat, lon, hr, cadence))
+					#	vel = 0
+					#rel_alt = tmp_alt - last_alt #Could allow for some 'jitter' in height here
+					#if rel_alt > 0:
+					#	self.upositive += rel_alt
+					#elif rel_alt < 0:
+					#	self.unegative -= rel_alt
+					#retorno.append((total_dist,tmp_alt, self.total_time,vel,lat,lon,hr,cadence))
 				
 				last_lat = tmp_lat
 				last_lon = tmp_lon
 				last_alt = tmp_alt
-				last_time = tmp_time
+				#last_time = tmp_time
+				if time_ is not None:
+					last_time = int(time_)
 
 		self.hr_average = 0
 		if len_validhrpoints > 0:
@@ -298,7 +378,7 @@ class Gpx:
 		dateTime = self.getDateTime(date_time.text)
 		zuluDateTime = dateTime[0].strftime("%Y-%m-%dT%H:%M:%SZ")
 		localDateTime = dateTime[1]
-		logging.debug(gpxFile+" | "+ date_time.text +" | " + zuluDateTime)
+		logging.debug(gpxFile+" | "+ date_time.text +" | " + zuluDateTime + " | " + str(localDateTime))
 		#print localDateTime
 		#return date_time.text
 		logging.debug("<<")
