@@ -54,66 +54,60 @@ from gui.windowmain import Main
 from gui.warning import Warning
 from lib.date import Date
 from lib.gpx import Gpx
-from lib.soapUtils import webService
+#from lib.soapUtils import webService
 from lib.ddbb import DDBB
 from lib.xmlUtils import XMLParser
 from lib.system import checkConf
 from lib.heartrate import *
 
-
-##TODO The below should all be able to be in the __init__ section, i.e. does not need to be global 
-
-# ERROR is the default log level
-PATH = os.environ['HOME']+"/.pytrainer"
-if not os.path.exists(PATH):
-	os.mkdir(PATH)
-LOG_FILENAME = PATH + "/log.out"
-
-#Setup usage and permitted options
-usage = """usage: %prog [options]
-
-For more help on valid options try:
-   %prog -h """
-parser = OptionParser(usage=usage)
-parser.set_defaults(log_level=logging.ERROR, validate=False, gm3=True, testimport=False)
-parser.add_option("-d", "--debug", action="store_const", const=logging.DEBUG, dest="log_level", help="enable logging at debug level")
-parser.add_option("-i", "--info", action="store_const", const=logging.INFO, dest="log_level", help="enable logging at info level")
-parser.add_option("-w", "--warn", action="store_const", const=logging.WARNING, dest="log_level", help="enable logging at warning level")
-parser.add_option("--valid", action="store_true", dest="validate", help="enable validation of files imported by plugins (details at info or debug logging level) - note plugin must support validation")
-parser.add_option("--check", action="store_true", dest="check", help="triggers database (only sqlite based) and configuration file sanity checks, adding fields if necessary. Backup of database is done before any change. Details at info or debug logging level")
-parser.add_option("--gmaps2", action="store_false", dest="gm3", help="Use old Google Maps API version (v2)")
-parser.add_option("--testimport", action="store_true", dest="testimport", help="EXPERIMENTAL: show new import functionality - for testing only USE AT YOUR OWN RISK")
-(options, args) = parser.parse_args()
-log_level = options.log_level
-validate = options.validate
-check = options.check
-gm3 = options.gm3
-testimport = options.testimport
-
-# Adding rotating support to default logger with customized format
-rotHandler = logging.handlers.RotatingFileHandler(LOG_FILENAME, maxBytes=100000, backupCount=5)
-formatter = logging.Formatter('%(asctime)s|%(levelname)s|%(module)s|%(funcName)s|%(message)s')
-rotHandler.setFormatter(formatter)
-logging.getLogger('').addHandler(rotHandler)
-logging.getLogger('').setLevel(log_level)
-
 class pyTrainer:
 	def __init__(self,filename = None, data_path = None): 
+		#Version constants
+		self.version ="1.7.2"
+		self.DB_version = 3
+		
+		#Setup usage and permitted options
+		usage = '''usage: %prog [options]
+		
+		For more help on valid options try:
+		   %prog -h '''
+		parser = OptionParser(usage=usage)
+		parser.set_defaults(log_level=logging.ERROR, validate=False, gm3=True, testimport=False)
+		parser.add_option("-d", "--debug", action="store_const", const=logging.DEBUG, dest="log_level", help="enable logging at debug level")
+		parser.add_option("-i", "--info", action="store_const", const=logging.INFO, dest="log_level", help="enable logging at info level")
+		parser.add_option("-w", "--warn", action="store_const", const=logging.WARNING, dest="log_level", help="enable logging at warning level")
+		parser.add_option("--valid", action="store_true", dest="validate", help="enable validation of files imported by plugins (details at info or debug logging level) - note plugin must support validation")
+		parser.add_option("--check", action="store_true", dest="check", help="triggers database (only sqlite based) and configuration file sanity checks, adding fields if necessary. Backup of database is done before any change. Details at info or debug logging level")
+		parser.add_option("--gmaps2", action="store_false", dest="gm3", help="Use old Google Maps API version (v2)")
+		parser.add_option("--testimport", action="store_true", dest="testimport", help="EXPERIMENTAL: show new import functionality - for testing only USE AT YOUR OWN RISK")
+		(options, args) = parser.parse_args()
+		#Populate startup options
+		self.log_level = options.log_level
+		self.validate = options.validate
+		self.check = options.check
+		self.gm3 = options.gm3
+		self.testimport = options.testimport
+		
+		PATH = os.environ['HOME']+"/.pytrainer"
+		if not os.path.exists(PATH):
+			os.mkdir(PATH)
+		LOG_FILENAME = PATH + "/log.out"
+		
+		# Adding rotating support to default logger with customized format
+		rotHandler = logging.handlers.RotatingFileHandler(LOG_FILENAME, maxBytes=100000, backupCount=5)
+		formatter = logging.Formatter('%(asctime)s|%(levelname)s|%(module)s|%(funcName)s|%(message)s')
+		rotHandler.setFormatter(formatter)
+		logging.getLogger('').addHandler(rotHandler)
+		logging.getLogger('').setLevel(self.log_level)
+
 		logging.debug('>>')
 		self.data_path = data_path
-		self.version ="1.7.1"
-		self.DB_version = 1
 		self.date = Date()
 		# Checking profile
+		#TODO configuration is first checked within profile, needs to be centralized - dgranda 2010.04.09
 		self.profile = Profile(self.data_path,self)
 		self.profile.isProfileConfigured()
-		#Populate startup options
-		self.log_level = log_level
-		self.validate = validate
-		self.check = check
-		self.gm3 = gm3
-		self.testimport = testimport
-
+		
 		self.windowmain = None
 
 		logging.debug('checking configuration...')
@@ -152,28 +146,32 @@ class pyTrainer:
 
 		#Preparamos el webservice	 
 		#TODO check reason for webservice - remove / change to optional start if not needed
-		gtk.gdk.threads_init()
-		self.webservice = webService(data_path,self.refreshWaypointView,self.newRecord)
-		self.webservice.start()
+		#gtk.gdk.threads_init()
+		#self.webservice = webService(data_path,self.refreshWaypointView,self.newRecord)
+		#self.webservice.start()
 
 		self.waypoint = Waypoint(data_path,self)
-		self.extension = Extension(data_path)
+		self.extension = Extension(data_path, self)
 		self.plugins = Plugins(data_path, self)
 		self.importdata = Importdata(data_path, self, self.configuration)
 		self.loadPlugins()
 		self.loadExtensions()
 		self.windowmain.createGraphs(RecordGraph,DayGraph,WeekGraph, MonthGraph,YearGraph,HeartRateGraph)
-		self.windowmain.createMap(Googlemaps,self.waypoint, self.gm3)
-		self.windowmain.createWaypointEditor(WaypointEditor,self.waypoint)
+		self.windowmain.createMap(Googlemaps,self.waypoint)
+		self.windowmain.createWaypointEditor(WaypointEditor,self.waypoint, parent=self)
 		self.windowmain.on_calendar_selected(None)
 		self.refreshMainSportList()	 
 		self.windowmain.run()
 		logging.debug('<<') 
+		
+	def set_logging_level(self,level):
+		logging.debug("Setting logger to level: "+ str(level))
+		logging.getLogger('').setLevel(level)
 
 	def quit(self): 
 		logging.debug('--')
 		logging.info("Exit!")
-		self.webservice.stop()
+		#self.webservice.stop()
 		self.windowmain.gtk_main_quit()
 		logging.shutdown()
 		sys.exit() # Any nonzero value is considered “abnormal termination” by shells and the like
@@ -210,7 +208,8 @@ class pyTrainer:
 			for (pluginFile, sport) in pluginFiles:
 				if os.path.isfile(pluginFile):
 					logging.info('File exists. Size: %d. Sport: %s' % (os.path.getsize(pluginFile), sport))
-					self.record.importFromGPX(pluginFile, sport)
+					if self.record.importFromGPX(pluginFile, sport) is None:
+						logging.error("Error importing file "+pluginFile)
  				else:
  					logging.error('File '+pluginFile+' not valid')
 		else:
@@ -222,9 +221,12 @@ class pyTrainer:
 	def runExtension(self,extension,id):
 		logging.debug('>>')
 		txtbutton,pathExtension,type = extension
-		if type == "record":
-			 #Si es record le tenemos que crear el googlemaps, el gpx y darle el id de la bbdd
-			 alert = self.extension.runExtension(pathExtension,id)
+		self.extensionClass = self.extension.importClass(pathExtension)
+		self.extensionClass.run(id)
+		#if type == "record":
+		#	#Si es record le tenemos que crear el googlemaps, el gpx y darle el id de la bbdd
+		#	alert = self.extension.runExtension(pathExtension,id)
+
 		logging.debug('<<')
 	 
 	def refreshMainSportList(self):
@@ -294,16 +296,17 @@ class pyTrainer:
 			 self.windowmain.actualize_recordview(record_list)
 
 		if view=="graphs":
-			 selected,iter = self.windowmain.recordTreeView.get_selection().get_selected()
-			 gpx_tracklist = []
-			 if iter:
+			selected,iter = self.windowmain.recordTreeView.get_selection().get_selected()
+			gpx_tracklist = []
+			gpx_laps = None
+			if iter:
 				id_record = selected.get_value(iter,0)
 				gpxfile = self.conf.getValue("gpxdir")+"/%s.gpx" %id_record
 				if os.path.isfile(gpxfile):
 					gpx = Gpx(self.data_path,gpxfile)
 					gpx_tracklist = gpx.getTrackList()
-					gpx_laps = gpx.getLaps()
-			 self.windowmain.actualize_recordgraph(gpx_tracklist, gpx_laps)
+					gpx_laps = self.record.getLaps(id_record)
+			self.windowmain.actualize_recordgraph(gpx_tracklist, gpx_laps)
 
 		if view=="map":
 			 self.refreshMapView()
@@ -327,12 +330,12 @@ class pyTrainer:
 			 self.windowmain.actualize_hrview(record_list,zones,karvonen_method)
 		logging.debug('<<')
 			 
-	def refreshMapView(self):
+	def refreshMapView(self, full_screen=False):
 		logging.debug('>>')
 		selected,iter = self.windowmain.recordTreeView.get_selection().get_selected()
 		id_record = selected.get_value(iter,0)
 		logging.debug('Trying to show map for record '+str(id_record))
-		self.windowmain.actualize_map(id_record)
+		self.windowmain.actualize_map(id_record, full_screen)
 		logging.debug('<<')
 
 	def refreshListRecords(self):
@@ -350,7 +353,7 @@ class pyTrainer:
 		self.windowmain.actualize_listview(record_list)
 		logging.debug('<<')
 	 
-	def refreshWaypointView(self,default_waypoint=False,redrawmap=1):
+	def refreshWaypointView(self,default_waypoint=None,redrawmap=1):
 		logging.debug('>>')
 		waypoint_list = self.waypoint.getAllWaypoints()
 		self.windowmain.actualize_waypointview(waypoint_list,default_waypoint,redrawmap)
@@ -364,12 +367,21 @@ class pyTrainer:
 		
 	def editExtensions(self):
 		logging.debug('>>')
+		before = self.extension.getActiveExtensions()
 		self.extension.manageExtensions()
+		after = self.extension.getActiveExtensions()
+		self.setExtensions(before, after)
 		logging.debug('<<')
 
 	def importData(self):
 		logging.debug('>>')
+		activeplugins_before = self.plugins.getActivePlugins()
 		self.importdata.runImportdata()
+		activeplugins_after = self.plugins.getActivePlugins()
+		#Need to check for plugins that have been disabled (were active and now are not)
+		self.setMenuPlugins(activeplugins_before, activeplugins_after)
+		self.refreshListRecords()
+		self.refreshGraphView(self.windowmain.selected_view)
 		logging.debug('<<')		
 		
 	def editGpsPlugins(self):
@@ -378,6 +390,12 @@ class pyTrainer:
 		self.plugins.managePlugins()
 		activeplugins_after = self.plugins.getActivePlugins()
 		#Need to check for plugins that have been disabled (were active and now are not)
+		self.setMenuPlugins(activeplugins_before, activeplugins_after)
+		logging.debug('<<')
+		
+	def setMenuPlugins(self, activeplugins_before, activeplugins_after):
+		logging.debug('>>')
+		#Need to check for plugins that have been disabled (were active and now are not)
 		for plugin in activeplugins_before:
 			if plugin not in activeplugins_after:
 				#disabled plugin -> need to unload plugin
@@ -390,6 +408,24 @@ class pyTrainer:
 				txtbutton = self.plugins.loadPlugin(plugin)
 				self.windowmain.addImportPlugin(txtbutton)
 		logging.debug('<<')
+		
+	def setExtensions(self, before, after):
+		logging.debug('>>')
+		#Need to check for extensions that have been disabled (were active and now are not)
+		for extension in before:
+			if extension not in after:
+				#disabled extension -> need to unload extension
+				print "Need to disable extension %s " % extension
+				txtbutton = self.extension.loadExtension(extension)
+				self.windowmain.removeExtension(txtbutton)
+		#Need to check for plugins that have been enabled (were not active and now are)
+		for extension in after:
+			if extension not in before:
+				#new active extension -> need to load extension
+				logging.debug("Enabling extension %s " % extension)
+				txtbutton = self.extension.loadExtension(extension)
+				self.windowmain.addExtension(txtbutton)
+		logging.debug('<<')
 
 	def newRecord(self,title=None,distance=None,time=None,upositive=None,unegative=None,bpm=None,calories=None,date=None,comment=None):
 		logging.debug('>>')
@@ -465,57 +501,3 @@ class pyTrainer:
 		logging.info('Setting DB version to: ' + str(self.DB_version))
 		self.configuration.setValue("pytraining","DB_version", str(self.DB_version))
 		logging.debug('<<')
-	
-	#def addDateTimeUTC(self): #TODO remove
-		"""12.07.2008 - dgranda
-		Adds date_time (UTC format) for each record (new column date_time_utc in table records). New in version 1.6.0.1
-		args: none
-		returns: none"""
-		'''logging.debug('>>')
-		# Retrieves info from all GPX files stored locally
-		listTracksGPX = self.record.shortFromLocal()
-		logging.debug('Retrieved info from local files: '+ str(listTracksGPX))
-		# Creates column date_time_utc in records table
-		try:
-			self.ddbb.addDateTimeUTC2ddbb()
-		except:
-			logging.error('Column date_time_utc already exists in DB')
-			traceback.print_exc()	
-		# Updates data
-		num=0
-		for track in listTracksGPX:
-			try:
-				# update records set date_time_utc="2008-07-11T10:21:31Z" where id_record='158';
-				logging.debug('Updating: '+str(track))
-				self.ddbb.update("records","date_time_utc",[track[1]], "id_record = %d" %int(track[2]))
-				num+=1
-			except:
-				logging.error('Error when updating data for track '+ track[2])
-				traceback.print_exc()
-		logging.info('Updated '+str(num)+' entries')
-		logging.debug('<<')'''
-		
-	#def checkPacesDB(self): #TODO remove
-		"""19.07.2008 - dgranda
-		Updates paces in DB (maxspeed<->maxpace | average<->pace). New in version 1.6.0.2
-		args: none
-		returns: none"""
-		'''logging.debug('>>')
-		# Retrieves info from DB: id_record,maxspeed,maxpace,average,pace
-		listPaces = self.ddbb.select("records", "id_record,maxspeed,maxpace,average,pace")
-		logging.debug('Retrieved info from db: '+ str(listPaces))
-		num=0
-		for entry in listPaces:
-			if entry[1]>0 and entry[3]>0:
-				tmpMax = "%d.%02d" %((3600/entry[1])/60,(3600/entry[1])%60)
-				tmpAve = "%d.%02d" %((3600/entry[3])/60,(3600/entry[3])%60)
-				try:
-					self.ddbb.update("records","maxpace,pace",[eval(tmpMax),eval(tmpAve)], "id_record = %d" %int(entry[0]))
-					num+=1
-				except:
-					logging.error('Error when updating data for track '+ entry[0])
-					traceback.print_last()
-			else:
-				logging.error('No pace info available for entry '+str(entry[0])+' in DB. Please check')
-		logging.info('Updated '+str(num)+' entries')
-		logging.debug('<<')'''
