@@ -19,12 +19,12 @@
 from gui.drawArea import DrawArea
 
 class MonthGraph:
-	def __init__(self, vbox = None, combovalue = None, combovalue2 = None):
-		self.drawarea = DrawArea(vbox)
+	def __init__(self, vbox = None, window = None, combovalue = None, combovalue2 = None):
+		self.drawarea = DrawArea(vbox, window)
 		self.combovalue = combovalue
 		self.combovalue2 = combovalue2
 
-	def drawgraph(self,values):
+	def drawgraph(self,values, daysInMonth):
 		xval = []
 		yval = []
 		xlab = []
@@ -36,8 +36,8 @@ class MonthGraph:
 		if value_selected < 0:
 			self.combovalue.set_active(0)
 			value_selected = 0
-		daysmonth,xlabel,ylabel,title,color = self.get_value_params(value_selected)
-		xvalues,yvalues = self.get_values(values,value_selected,daysmonth)
+		xlabel,ylabel,title,color = self.get_value_params(value_selected)
+		xvalues,yvalues = self.get_values(values,value_selected,daysInMonth)
 
 		xval.append(xvalues)
 		yval.append(yvalues)
@@ -54,30 +54,30 @@ class MonthGraph:
 			value_selected2 = 0
 		if value_selected2 > 0:
 			value_selected2 = value_selected2-1
-			daysmonth,xlabel,ylabel,title,color = self.get_value_params(value_selected2)
-			xvalues,yvalues = self.get_values(values,value_selected2,daysmonth)
+			xlabel,ylabel,title,color = self.get_value_params(value_selected2)
+			xvalues,yvalues = self.get_values(values,value_selected2,daysInMonth)
 			xval.append(xvalues)
 			yval.append(yvalues)
 			xlab.append(xlabel)
 			ylab.append(ylabel)
-			tit.append("")
+			tit.append(title)
 			col.append(color)
 		self.drawarea.stadistics("bars",xval,yval,xlab,ylab,tit,col)
 
 	def get_value_params(self,value):
 		if value == 0:
-			return 32,_("day"),_("Kilometers"),_("Daily kilometers"),"y"
+			return _("day"),_("Distance (km)"),_("Daily Distance"),"y"
 		elif value == 1:
-			return 32,_("day"),_("Time in Hours"), _("Daily Time"),"b"
+			return _("day"),_("Time (hours)"), _("Daily Time"),"b"
 		elif value == 2:
-			return 32,_("day"),_("Beats per Minute"), _("Daily Beats"),"r"
+			return _("day"),_("Average Heart Rate (bpm)"), _("Daily Average Heart Rate"),"r"
 		elif value == 3:
-			return 32,_("day"),_("Average (km/h)"), _("Daily Averages"),"g"
+			return _("day"),_("Average Speed (km/h)"), _("Daily Average Speed"),"g"
 		elif value == 4:
-			return 32,_("day"),_("Calories"), _("Daily Calories"),"b"
+			return _("day"),_("Calories"), _("Daily Calories"),"b"
 
-	def get_values(self,values,value_selected,daysmonth):
-		#hacemos una relacion entre el value_selected y los values
+	def get_values(self,values,value_selected,daysInMonth):
+		#hacemos una relacion entre el value_selected y los values / we make a relation between value_selected and the values
 		conv = {
 			0: 1, #value 0 es kilometros (1)
 			1: 2, #value 1 es tiempo (2)
@@ -87,13 +87,13 @@ class MonthGraph:
 			}
 		list_values = {}
 		list_average = {}
-		for i in range(1,32):
+		for i in range(1,daysInMonth+1):
 			list_values[i]=0
 			list_average[i]=0
 
 		value_sel = conv[value_selected]
 		for value in values:
-			#si la opcion es tiempo lo pasamos a horas
+			#si la opcion es tiempo lo pasamos a horas / if the option is time we passed it to hours
 			if (value_sel == 2):
 				graph_value = self.getFloatValue(value[value_sel])/3600
 			else:
@@ -102,18 +102,19 @@ class MonthGraph:
 			date = value[0]
 			year,month,day = date.split("-")
 
-			#si es una opcion de suma de absolutos:
-                        if ((value_selected == 0) or (value_selected==1) or (value_selected==4)):
-                                list_values[int(day)] += graph_value
-                        #si se trata de calcular medias:
-                        else:
-                                list_values[int(day)] += graph_value
-                                list_average[int(day)] += 1
+			#si es una opcion de suma de absolutos / if it is an option of sum of absolute
+			if ((value_selected == 0) or (value_selected==1) or (value_selected==4)):
+				list_values[int(day)] += graph_value
+			#si se trata de calcular medias / if one is to calculate averages:
+			else:
+				if graph_value is not None and graph_value != 0:
+					list_values[int(day)] += graph_value
+					list_average[int(day)] += 1
 
 		xunits = []
 		yunits = []
-		for i in range (0,daysmonth):
-                        xunits.append(i)
+		for i in range (1,daysInMonth+1):
+			xunits.append(i)
 			yunits.append(float(0))
 	
 		for value in list_values:
