@@ -48,13 +48,24 @@ class Record:
 		logging.debug('<<')
 
 	def newRecord(self, list_sport, date, title=None, distance=None, time=None, upositive=None, unegative=None, bpm=None, calories=None, comment=None):
+		logging.debug('>>')
 		self.recordwindow = WindowRecord(self.data_path, list_sport,self, date, title, distance, time, upositive, unegative, bpm, calories, comment)
 		self.recordwindow.run()
 		logging.debug('<<')
+		
+	def newMultiRecord(self, activities, list_sport):
+		logging.debug('>>')
+		#activities (activity_id, start_time, distance, duration, sport, gpx_file)
+		self.recordwindow = WindowRecord(self.data_path, list_sport, parent=self, windowTitle="Modify details before importing")
+		self.recordwindow.populateMultiWindow(activities)
+		self.recordwindow.run()
+		return self.recordwindow.getActivityData()
+		logging.debug('<<')
 
 	def editRecord(self,id_record,list_sport):
 		logging.debug('>>')
-		record = self.ddbb.select("records", "*", "id_record=\"%s\"" %id_record)
+		#record = self.ddbb.select("records", "*", "id_record=\"%s\"" %id_record)
+		record = self.ddbb.select("records", "id_record, date, sport, distance, time, beats, average, calories, comments, gpslog, title, upositive, unegative, maxspeed, maxpace, pace, maxbeats, date_time_utc, date_time_local", "id_record=\"%s\"" %id_record)
 		logging.debug('retrieving data from DB: '+str(record))
 		gpxfile = self.conf.getValue("gpxdir")+"/%d.gpx"%int(id_record)
 		logging.debug('gpx file associated: '+gpxfile)
@@ -69,10 +80,11 @@ class Record:
 		self.recordwindow.run()
 		logging.debug('<<')
 	
-	def removeRecord(self,id_record): #TODO remember to update once laps are in DB
+	def removeRecord(self,id_record):
 		logging.debug('>>')
 		record = self.ddbb.delete("records", "id_record=\"%s\"" %id_record)
-		logging.debug('removed record '+str(id_record)+' from bbdd')
+		laps = self.ddbb.delete("laps", "record=\"%s\"" %id_record)
+		logging.debug('removed record '+str(id_record)+' (and associated laps) from DB')
 		gpxfile = self.conf.getValue("gpxdir")+"/%d.gpx"%int(id_record)
 		if os.path.isfile(gpxfile):
 			os.remove(gpxfile)
@@ -147,22 +159,27 @@ class Record:
 		logging.debug('<<')
 		return keys,values
 
-	def insertRecord(self, list_options):
+	def insertRecord(self, list_options, laps=None):
 		logging.debug('>>')
+		#Create entry for activity in records table
 		if list_options is None:
-			logging.debug('No data provided, abort adding entry')
-			return None
-		elif list_options["rcd_time"] == [0, 0, 0]:
-			logging.debug('Activity has no duration, abort adding entry')
+			logging.info('No data provided, abort adding entry')
 			return None
 		logging.debug('list_options: '+str(list_options))
 		cells,values = self._formatRecordNew(list_options)
 		self.ddbb.insert("records",cells,values)
 		logging.debug('DB updated: '+str(cells)+' | '+str(values))
+		id_record = self.ddbb.lastRecord("records")
+		#Create entry(s) for activity in laps table
+		if laps is not None:
+			for lap in laps:
+				lap['record'] = id_record #Add reference to entry in record table
+				lap_keys = ", ".join(map(str, lap.keys()))
+				lap_values = lap.values()
+				self.insertLaps(lap_keys,lap.values())
 		gpxOrig = list_options["rcd_gpxfile"]
 		if os.path.isfile(gpxOrig):
 			gpxDest = self.conf.getValue("gpxdir")
-			id_record = self.ddbb.lastRecord("records")
 			gpxNew = gpxDest+"/%d.gpx"%id_record
 			shutil.move(gpxOrig, gpxNew)
 			logging.debug('Moving '+gpxOrig+' to '+gpxNew)
@@ -175,37 +192,65 @@ class Record:
 		Moves GPX file to store destination and updates database
 		args: path to source GPX file"""
 		logging.debug('--')
-		return self.insertRecord(self.summaryFromGPX(gpxOrig, entry))
-		
+		(list_options, gpx_laps) = self.summaryFromGPX(gpxOrig, entry)
+		if list_options is None:
+			return None
+		return self.insertRecord(list_options, laps=gpx_laps)
+	
+	def lapsFromGPX(self, gpx):
+		logging.debug('>>')
+		laps = []
+		gpxLaps = gpx.getLaps() 
+		for lap in gpxLaps:
+			lap_number = gpxLaps.index(lap)
+			tmp_lap = {}
+			tmp_lap['record'] = ""
+			tmp_lap['lap_number'] = lap_number
+			tmp_lap['elapsed_time'] = lap[0]
+			tmp_lap['distance'] = lap[4]
+			tmp_lap['start_lat'] = lap[5]
+			tmp_lap['start_lon'] = lap[6]
+			tmp_lap['end_lat'] = lap[1]
+			tmp_lap['end_lon'] = lap[2]
+			tmp_lap['calories'] = lap[3]
+			laps.append(tmp_lap)
+		logging.debug('<<')
+		return laps
+			
 	def summaryFromGPX(self, gpxOrig, entry):
 		"""29.03.2008 - dgranda
 		Retrieves info which will be stored in DB from GPX file
 		args: path to source GPX file
-		returns: list with fields and values"""
+		returns: list with fields and values, list of laps 
+		"""
 		logging.debug('>>')
 		gpx = Gpx(self.data_path,gpxOrig)
 		distance, time, maxspeed, maxheartrate = gpx.getMaxValues()
-		if time == 0: #invalid record
-			return None
+		#if time == 0: #invalid record
+		#	print "Invalid record"
+		#	return (None, None)
 		upositive,unegative = gpx.getUnevenness()
-		speed = distance*3600/time
-		time_hhmmss = [time//3600,(time/60)%60,time%60]
+		if time > 0:
+			speed = distance*3600/time
+			time_hhmmss = [time//3600,(time/60)%60,time%60]
+		else:
+			speed = 0
+			time_hhmmss = [0,0,0]
 		summaryRecord = {}
 		summaryRecord['rcd_gpxfile'] = gpxOrig
 		summaryRecord['rcd_sport'] = entry[0]
 		summaryRecord['rcd_date'] = gpx.getDate()
 		summaryRecord['rcd_calories'] = gpx.getCalories()
-		logging.debug('rcd_calories: ' + str(summaryRecord['rcd_calories']))
 		summaryRecord['rcd_comments'] = ''
 		summaryRecord['rcd_title'] = ''
 		summaryRecord['rcd_time'] = time_hhmmss #ToDo: makes no sense to work with arrays
 		summaryRecord['rcd_distance'] = "%0.2f" %distance 
 		if speed == 0:
-			summaryRecord['rcd_pace'] = 0
+			summaryRecord['rcd_pace'] = "0"
 		else:
 			summaryRecord['rcd_pace'] = "%d.%02d" %((3600/speed)/60,(3600/speed)%60)
 		if maxspeed == 0:
-			summaryRecord['rcd_maxpace'] = 0
+			summaryRecord['rcd_maxpace'] = "0"
 		else:
 			summaryRecord['rcd_maxpace'] = "%d.%02d" %((3600/maxspeed)/60,(3600/maxspeed)%60)
 		summaryRecord['rcd_average'] = speed
@@ -214,15 +259,16 @@ class Record:
 		summaryRecord['rcd_maxbeats'] = maxheartrate
 		summaryRecord['rcd_upositive'] = upositive
 		summaryRecord['rcd_unegative'] = unegative
-		if entry[1]=="": # coming from new track dialog (file opening)
-			summaryRecord['date_time_utc'], summaryRecord['date_time_local'] = gpx.getStartTimeFromGPX(gpxOrig)
-		else: # coming from GPS device
-			summaryRecord['date_time_utc'] = entry[1]
-			summaryRecord['date_time_local'] = entry[1]
-			print "#TODO fix record summaryRecord local and utc time..."
+		if entry[1]=="": # coming from new track dialog (file opening)												#TODO This if-else needs checking
+			summaryRecord['date_time_utc'], summaryRecord['date_time_local'] = gpx.getStartTimeFromGPX(gpxOrig)		#
+		else: # coming from GPS device																				#
+			summaryRecord['date_time_utc'] = entry[1]																#
+			summaryRecord['date_time_local'] = entry[1]																#
+			print "#TODO fix record summaryRecord local and utc time..."											#
 		logging.debug('summary: '+str(summaryRecord))
+		laps = self.lapsFromGPX(gpx)
 		logging.debug('<<')
-		return summaryRecord
+		return summaryRecord, laps
 
 	def updateRecord(self, list_options, id_record):
 		logging.debug('>>')
@@ -262,6 +308,34 @@ class Record:
 					"sports.name,date,distance,time,beats,comments,average,calories,id_record,maxspeed,maxbeats,date_time_utc,date_time_local",
 					"date=\"%s\" and records.sport=sports.id_sports" %date)
 
+	def getLaps(self, id_record):
+		logging.debug('--')
+		laps = self.ddbb.select("laps", 
+					"id_lap, record, elapsed_time, distance, start_lat, start_lon, end_lat, end_lon, calories, lap_number",
+					"record=\"%s\"" % id_record)
+		if laps is None or laps == []:  #No laps stored - update DB
+			logging.debug("No laps in DB for record %d" % id_record)
+			gpx_dest = self.conf.getValue("gpxdir")
+			gpxfile = gpx_dest+"/%d.gpx"%id_record
+			gpx = Gpx(self.data_path,gpxfile)
+			laps = self.lapsFromGPX(gpx)
+			if laps is not None:
+				for lap in laps:
+					lap['record'] = id_record #Add reference to entry in record table
+					lap_keys = ", ".join(map(str, lap.keys()))
+					lap_values = lap.values()
+					self.insertLaps(lap_keys,lap.values())
+			#Try to get lap info again #TODO? refactor				
+			laps = self.ddbb.select("laps", 
+					"id_lap, record, elapsed_time, distance, start_lat, start_lon, end_lat, end_lon, calories, lap_number",
+					"record=\"%s\"" % id_record)
+		return laps 
+					
+	def insertLaps(self, cells, values):
+		logging.debug('--')
+		logging.debug("Adding lap information: " + ", ".join(map(str, values)))
+		self.ddbb.insert("laps",cells,values)
+		
 	def getrecordPeriod(self,date_ini, date_end, sport=None):
 		#TODO This is essentially the same as getrecordPeriodSport (except date ranges) - need to look at merging the two
 		tables = "records,sports"
@@ -376,7 +450,7 @@ class Record:
 			logging.debug('Found '+str(len(tracks))+' tracks')
 			self._select_trkfromgpx(gpxfile,tracks)
 		else:
-			msg = _("pyTrainer cant import data from your gpx file")
+			msg = _("pyTrainer can't import data from your gpx file")
 			from gui.warning import Warning
 			warning = Warning(self.data_path)
 			warning.set_text(msg)
@@ -437,16 +511,21 @@ class Record:
 		Add a record from a valid pytrainer type GPX file
 		"""	
 		logging.debug('>>')
-		logging.info('Retrieving data from '+gpxFile)
-		if not sport:
-			sport = "import"
-		entry = [sport,""]
-		entry_id = self.insertNewRecord(gpxFile, entry)
-		if entry_id is None:
-			logging.error("Entry not created for file %s" % gpxFile)
+		entry_id = None
+		if not os.path.isfile(gpxFile):
+			logging.error("Invalid file: " +gpxFile)
 		else:
-			logging.info("Entry %d has been added" % entry_id)
+			logging.info('Retrieving data from '+gpxFile)
+			if not sport:
+				sport = "import"
+			entry = [sport,""]
+			entry_id = self.insertNewRecord(gpxFile, entry)
+			if entry_id is None:
+				logging.error("Entry not created for file %s" % gpxFile)
+			else:
+				logging.info("Entry %d has been added" % entry_id)
 		logging.debug('<<')
+		return entry_id
 
 	#def importFromGTRNCTR(self,gtrnctrFile): #TODO remove
 		"""22.03.2008 - dgranda
